@@ -25,7 +25,7 @@ use Pod::Usage qw(pod2usage);
 use Geo::BUFR;
 
 # Will be used if neither --tablepath nor $ENV{BUFR_TABLES} is set
-use constant DEFAULT_TABLE_PATH => '/usr/local/lib/emos/bufrtables';
+use constant DEFAULT_TABLE_PATH => '/usr/local/lib/bufrtables';
 
 # Parse command line options
 our %option = ();
@@ -88,7 +88,7 @@ if ($option{tablepath}) {
     # If no --tablepath option, use the BUFR_TABLES environment variable
     Geo::BUFR->set_tablepath($ENV{BUFR_TABLES});
 } else {
-    # If all else fails, use the libemos bufrtables
+    # If all else fails, use the libbufr bufrtables
     Geo::BUFR->set_tablepath(DEFAULT_TABLE_PATH);
 }
 
